# ReadMe

Repository for BART Survival Package. 

Based on the PYMC Bayesian Additive Regression Trees implementation, this package provides a preconfigured model for BART applied in the survival setting and necessary data processing algorithms to implement such model.
